"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.CheckpointDao = exports.Checkpoint = void 0;
const sqlite3_1 = require("sqlite3");
const fs = require("fs");
const sqlite3 = (0, sqlite3_1.verbose)();
let db;
class Checkpoint {
}
exports.Checkpoint = Checkpoint;
class CheckpointDao {
    static async init() {
        if (!fs.existsSync('./db')) {
            fs.mkdirSync('./db', { recursive: true });
        }
        db = new sqlite3.Database(`./db/checkpoints.db`);
        await this.run('PRAGMA journal_mode=WAL');
        console.log('[Distributor Checkpoint] Initialized.');
        const createCheckpointTableQuery = `CREATE TABLE IF NOT EXISTS data_publish_checkpoints("id" integer, "data_type" varchar NOT NULL, "mode" string NOT NULL, "cursor" string NOT NULL, PRIMARY KEY (id))`;
        await this.run(createCheckpointTableQuery);
        const createDataTypeModeIndex = `CREATE UNIQUE INDEX IF NOT EXISTS "uniq_idx_data_type_mode" ON "data_publish_checkpoints" ("data_type", "mode")`;
        await this.run(createDataTypeModeIndex);
    }
    static async getCheckpoint(dataType, mode) {
        const query = `SELECT * FROM data_publish_checkpoints WHERE data_type = ? AND mode = ?`;
        return await this.get(query, [dataType, mode]);
    }
    static async upsertCheckpoint(dataType, mode, cursor) {
        const query = `INSERT INTO data_publish_checkpoints (data_type, mode, cursor) VALUES (?, ?, ?) 
                    ON CONFLICT(data_type, mode) DO UPDATE SET cursor = ?`;
        await this.run(query, [dataType, mode, cursor, cursor]);
    }
    static async get(sql, params = []) {
        return new Promise((resolve, reject) => {
            db.get(sql, params, (err, result) => {
                if (err) {
                    console.log('Error running sql: ' + sql);
                    console.log(err);
                    reject(err);
                }
                else {
                    resolve(result);
                }
            });
        });
    }
    static async run(sql, params = [] || {}) {
        return new Promise((resolve, reject) => {
            db.run(sql, params, function (err) {
                if (err) {
                    console.log('[Distributor Checkpoint] Error running sql ' + sql);
                    console.log(err);
                    reject(err);
                }
                else {
                    resolve({ id: this.lastID });
                }
            });
        });
    }
    static close() {
        db.close();
    }
}
exports.CheckpointDao = CheckpointDao;
//# sourceMappingURL=checkpoints.js.map