"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.extractValuesFromArray = exports.extractValues = exports.all = exports.get = exports.run = exports.close = exports.readFromDB = void 0;
const serialization_1 = require("../utils/serialization");
const sqlite3_1 = require("sqlite3");
const readFromDB = async (dbPath, dbName) => {
    console.log('Read From DB -> dbName: ', dbName, 'dbPath: ', dbPath);
    const db = new sqlite3_1.Database(dbPath, (err) => {
        if (err) {
            console.log('❌ Error opening database:', err);
            throw err;
        }
    });
    await run(db, 'PRAGMA journal_mode=WAL');
    console.log(`✅ Database: ${dbName} initialized.`);
    return db;
};
exports.readFromDB = readFromDB;
/**
 * Closes Database Connection Gracefully
 */
async function close(db, dbName) {
    try {
        console.log(`Terminating ${dbName} Database/Indexer Connections...`);
        await new Promise((resolve, reject) => {
            db.close((err) => {
                if (err) {
                    console.error(`Error closing ${dbName} Database Connection.`);
                    console.log(err);
                    reject(err);
                }
                else {
                    console.log(`${dbName} Database connection closed.`);
                    resolve();
                }
            });
        });
    }
    catch (err) {
        console.error(`Error thrown in ${dbName} db close() function: `);
        console.error(err);
    }
}
exports.close = close;
async function run(db, sql, params = [] || {}) {
    return new Promise((resolve, reject) => {
        db.run(sql, params, function (err) {
            if (err) {
                console.log('Error running sql ' + sql);
                console.log(err);
                reject(err);
            }
            else {
                resolve({ id: this.lastID });
            }
        });
    });
}
exports.run = run;
async function get(db, sql, params = []) {
    return new Promise((resolve, reject) => {
        db.get(sql, params, (err, result) => {
            if (err) {
                console.log('Error running sql: ' + sql);
                console.log(err);
                reject(err);
            }
            else {
                resolve(result);
            }
        });
    });
}
exports.get = get;
async function all(db, sql, params = []) {
    return new Promise((resolve, reject) => {
        db.all(sql, params, (err, rows) => {
            if (err) {
                console.log('Error running sql: ' + sql);
                console.log(err);
                reject(err);
            }
            else {
                resolve(rows);
            }
        });
    });
}
exports.all = all;
function extractValues(object) {
    try {
        const inputs = [];
        for (const column of Object.keys(object)) {
            if (Object.prototype.hasOwnProperty.call(object, column)) {
                // eslint-disable-next-line security/detect-object-injection
                let value = object[column];
                if (typeof value === 'object')
                    value = (0, serialization_1.SerializeToJsonString)(value);
                inputs.push(value);
            }
        }
        return inputs;
    }
    catch (e) {
        console.log(e);
    }
}
exports.extractValues = extractValues;
function extractValuesFromArray(arr) {
    try {
        const inputs = [];
        for (const object of arr) {
            for (const column of Object.keys(object)) {
                if (Object.prototype.hasOwnProperty.call(object, column)) {
                    let value = Reflect.get(object, column);
                    if (typeof value === 'object')
                        value = (0, serialization_1.SerializeToJsonString)(value);
                    inputs.push(value);
                }
            }
        }
        return inputs;
    }
    catch (e) {
        console.log(e);
    }
}
exports.extractValuesFromArray = extractValuesFromArray;
//# sourceMappingURL=sqlite3storage.js.map