"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.initRMQModeHttpServer = void 0;
const Logger = require("../Logger");
const Config_1 = require("../Config");
const cors_1 = require("@fastify/cors");
const fastify_1 = require("fastify");
const rate_limit_1 = require("@fastify/rate-limit");
const lib_types_1 = require("@shardeum-foundation/lib-types");
const initRMQModeHttpServer = async (rmqHealthCheck) => {
    const fastifyServer = (0, fastify_1.default)({
        logger: false,
    });
    await fastifyServer.register(cors_1.default);
    await fastifyServer.register(rate_limit_1.default, {
        global: true,
        max: Config_1.config.RATE_LIMIT,
        timeWindow: 10,
        allowList: ['127.0.0.1', '0.0.0.0'], // Excludes local IPs from rate limits
    });
    await fastifyServer.register(function (fastify, opts, done) {
        fastify.get('/distributor/is-healthy', async (_, res) => {
            const distributorHealth = await rmqHealthCheck.distributorHealth();
            return res.status(200).send(distributorHealth);
        });
        fastify.get('/collector/is-healthy', async (_, res) => {
            const collectorHealth = await rmqHealthCheck.collectorHealth();
            return res.status(200).send(collectorHealth);
        });
        done();
    });
    fastifyServer.addContentTypeParser('application/json', { parseAs: 'string' }, (req, body, done) => {
        try {
            const jsonString = typeof body === 'string' ? body : body.toString('utf8');
            done(null, lib_types_1.Utils.safeJsonParse(jsonString));
        }
        catch (err) {
            err.statusCode = 400;
            done(err, undefined);
        }
    });
    fastifyServer.setReplySerializer((payload) => {
        return lib_types_1.Utils.safeStringify(payload);
    });
    // Start server and bind to port on all interfaces
    fastifyServer.listen({
        port: Config_1.config.MQ_DISTRIBUTOR_SERVER_PORT,
        host: '0.0.0.0',
    }, (err) => {
        Logger.mainLogger.debug('MQ Health Check Server listening on port', Config_1.config.MQ_DISTRIBUTOR_SERVER_PORT);
        if (err) {
            fastifyServer.log.error(err);
            process.exit(1);
        }
        Logger.mainLogger.debug('MQ Health Check started');
    });
};
exports.initRMQModeHttpServer = initRMQModeHttpServer;
//# sourceMappingURL=rmq_healthcheck_server.js.map