"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const Config_1 = require("../Config");
const checkpoints_1 = require("../dbstore/checkpoints");
const cycles_1 = require("../dbstore/cycles");
const axios_1 = require("axios");
class DistributorHealthResp {
}
class CollectorHealthResp {
}
class RMQMetric {
    constructor(name, messages, memory) {
        this.name = name;
        this.messages = messages;
        this.memory = memory;
    }
}
class RMQModeHeathCheck {
    constructor(rmqPublisher) {
        this.rmqPublisher = rmqPublisher;
    }
    async distributorHealth() {
        const cycles = (await (0, cycles_1.queryLatestCycleRecords)(1));
        const checkpoint = await checkpoints_1.CheckpointDao.getCheckpoint('cycle', Config_1.distributorMode.MQ);
        const distributorHealthResp = new DistributorHealthResp();
        if (cycles.length > 0) {
            distributorHealthResp.lastCycleInDistributorDB = cycles[0].counter;
        }
        if (checkpoint != null) {
            distributorHealthResp.lastCyclePublishedByDistributor = parseInt(checkpoint.cursor);
        }
        distributorHealthResp.lastCycleCursorUpdatedTimestamp = this.rmqPublisher.getCursorUpdatedAt();
        return distributorHealthResp;
    }
    async collectorHealth() {
        const collectorHealthResp = new CollectorHealthResp();
        collectorHealthResp.cycles = [];
        collectorHealthResp.receipts = [];
        collectorHealthResp.originalTxs = [];
        /*
        - get queues bound to exchanges where distributor publishes messages
        - for all queues, get metrics and format the response
        */
        const queueBindingsForCycles = await this.getQueues(process.env.RMQ_CYCLES_EXCHANGE_NAME);
        const queueBindingsForReceipts = await this.getQueues(process.env.RMQ_RECEIPTS_EXCHANGE_NAME);
        const queueBindingsForTxs = await this.getQueues(process.env.RMQ_ORIGINAL_TXS_EXCHANGE_NAME);
        for (const queue of queueBindingsForCycles) {
            const metrics = await this.getQueueMetrics(queue);
            if (metrics !== null) {
                collectorHealthResp.cycles.push(metrics);
            }
        }
        for (const queue of queueBindingsForReceipts) {
            const metrics = await this.getQueueMetrics(queue);
            if (metrics !== null) {
                collectorHealthResp.receipts.push(metrics);
            }
        }
        for (const queue of queueBindingsForTxs) {
            const metrics = await this.getQueueMetrics(queue);
            if (metrics !== null) {
                collectorHealthResp.originalTxs.push(metrics);
            }
        }
        return collectorHealthResp;
    }
    async getQueues(exchange) {
        const queues = [];
        const url = `${process.env.RMQ_MGMT_ENDPOINT}/api/exchanges/%2F/${exchange}/bindings/source`;
        try {
            const response = await axios_1.default.get(url, {
                auth: {
                    username: process.env.RMQ_USER,
                    password: process.env.RMQ_PASS,
                },
            });
            const bindings = response.data;
            bindings.forEach((binding) => {
                if (binding.destination_type === 'queue') {
                    queues.push(binding.destination);
                }
            });
            return queues;
        }
        catch (e) {
            const err = e;
            console.log(`Error while querying queues for exchange: ${exchange}. Err: ${err.stack}`);
            return null;
        }
    }
    async getQueueMetrics(queue) {
        try {
            const url = `${process.env.RMQ_MGMT_ENDPOINT}/api/queues/%2F/${queue}`;
            const response = await axios_1.default.get(url, {
                auth: {
                    username: process.env.RMQ_USER,
                    password: process.env.RMQ_PASS,
                },
            });
            const { name, messages, memory } = response.data;
            return new RMQMetric(name, messages, memory);
        }
        catch (e) {
            console.log(`Error while querying metrics for queue: ${queue}. Err: ${e}`);
            return null;
        }
    }
}
exports.default = RMQModeHeathCheck;
//# sourceMappingURL=rmq_healthcheck_service.js.map