"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDistributorSecretKey = exports.getDistributorInfo = exports.initLogger = exports.setHashKey = void 0;
const path_1 = require("path");
const fs_1 = require("fs");
const Config_1 = require("../Config");
const crypto = require("./Crypto");
const Logger = require("../Logger");
const lib_types_1 = require("@shardeum-foundation/lib-types");
const distributorInfo = {
    ip: '',
    port: -1,
    publicKey: '',
    secretKey: '',
};
function setHashKey(key) {
    crypto.setCryptoHashKey(key);
}
exports.setHashKey = setHashKey;
function initLogger() {
    let logsConfig;
    try {
        logsConfig = lib_types_1.Utils.safeJsonParse((0, fs_1.readFileSync)((0, path_1.resolve)(__dirname, '../../../distributor-log.json'), 'utf8'));
    }
    catch (err) {
        console.log('Failed to parse distributor log file:', err);
    }
    const logDir = `${Config_1.config.DISTRIBUTOR_LOGS}`;
    const baseDir = '.';
    logsConfig.dir = logDir;
    Logger.initLogger(baseDir, logsConfig);
    // Set distributor info from config
    distributorInfo.ip = Config_1.config.DISTRIBUTOR_IP;
    distributorInfo.port = Config_1.config.DISTRIBUTOR_PORT;
    distributorInfo.publicKey = Config_1.config.DISTRIBUTOR_PUBLIC_KEY;
    distributorInfo.secretKey = Config_1.config.DISTRIBUTOR_SECRET_KEY;
}
exports.initLogger = initLogger;
function getDistributorInfo() {
    const sanitizedDistributorInfo = { ...distributorInfo };
    delete sanitizedDistributorInfo.secretKey;
    return sanitizedDistributorInfo;
}
exports.getDistributorInfo = getDistributorInfo;
function getDistributorSecretKey() {
    return distributorInfo.secretKey;
}
exports.getDistributorSecretKey = getDistributorSecretKey;
//# sourceMappingURL=index.js.map